Oil prices and interest rates: What to watch in 2015 - The Globe and Mail
Description: Globe and Mail economics reporter David Parkinson asks four notable economists to share their views on the key issue that will grab their attention in the new year
Keywords: Royal Bank of Canada;oil;economy;commodity;oil prices;interest rates;euro zone;economics reporter;global economy;Canadian dollar;foreign debt;diversified commodity economies;interest rate response;economic activity picks;chief economist;global monetary policy;world commodity prices;Russia;Japan;China;Canada;United Kingdom;Europe;India;United States of America;Putin;Energy;

- Home»
- Report on Business»
- International Business

Global monetary policy is expected to loosen in the new year, driving up prices for precious metals and improving mining prospects. (Sondeep Shankar)

# Oil prices and interest rates: What to watch in 2015 Add to ...

David Parkinson

The Globe and Mail

Published Monday, Dec. 29 2014, 6:00 PM EST

Last updated Monday, Dec. 29 2014, 7:21 PM EST

- Comments
- Print /
  License
- AA

Oil. Russia. Interest rates. The United States. Europe. Commodities. China. Trade. Japan. The global economy enters 2015 with a lot on its mind, and a long list of competing storylines set to develop as the year progresses. Here, four notable economists share their views on the key issue that will grab their attention in 2015 – and how it might unfold, for better or worse.

#### More Related to this Story

- Let’s look on the bright side of the Canadian, global economy

- The year of uncertainty: Retailers brace for a rocky 2015

- BREAKINGVIEWS Bad ideas catching up with Latin America in 2015

Eric Lascelles

Chief economist, RBC Global Asset Management – Toronto

Collapsing oil prices are poised to reverberate across 2015. If current pricing sticks, global producers will lose over a trillion dollars in annual profits, crimping their investment intentions and impairing their ability to pay dividends and debts.

Oil-exporting nations – Canada among them – naturally suffer, with the greatest agony reserved for emerging-market members who must perversely raise interest rates to halt capital flight and combat ballooning U.S.-denominated debt loads.

Desperate times lead to desperate measures, meaning Russia and the Middle East must be watched with an eagle eye next year.

However, let us not lose sight of the bigger picture. Oil’s extreme dislocation should partially unwind in 2015. After all, oil supply outpaces demand by a mere 2 per cent. There is no need for extreme cutbacks, especially if demand grows as enthusiastically as our models indicate.

For that matter, the global economy actually likes low oil prices. For all of the bellyaching, every dollar lost by oil producers is more than recovered across a diffuse set of oil consumers. Indeed, the combination of low oil prices, low bond yields and weakening exchange rates should help revive the moribund European and Japanese economies. This could prove to be the most lasting consequence of oil’s not-so-excellent adventure.

Julian Jessop

Chief global economist, Capital Economics – London

The year 2014 closed with a focus on the oil price, but developments in other commodity markets will also be worth watching in 2015. The knock-on effects could work in either direction.

We expect the price of oil to remain low. As energy is an important cost in the production and transportation of other commodities, this is one reason to expect price pressures more generally to be weak.

Nonetheless, most countries – and the world as a whole – should be better off as a result of lower oil prices, notably China and India. Of the advanced economies, Japan is the biggest winner, but there should also be sizable boosts to the U.S., euro zone and Britain. The upshot is that cheaper oil should support a rebound in the prices of industrial metals as economic activity picks up.

What’s more, China and India are the two largest markets for gold. While inflation will be lower as a result of the fall in oil prices, global monetary policy is also likely to be looser for longer. We, therefore, expect base and precious metals prices to do well in 2015, improving the prospects for miners and the more diversified commodity economies.

Christopher Ragan

Professor of economics, McGill University – Montreal

What should we expect from the world of central banking in 2015? I see two major forces.

First, given that real gross domestic product in the euro zone is still 2 per cent below the 2008 level, there’s a pretty clear economic case for more fiscal and monetary stimulus. On the other hand, the political forces in opposition to such actions continue to be massive. My best guess for 2015 is that the euro zone will continue to muddle through, without much new stimulus of any kind.

Meanwhile, the United States is showing ever-more promising signs of an economic renaissance. The Federal Reserve’s balance sheet has stopped its expansion, and most observers think that policy interest rates will begin their ascent in 2015. While such rate increases may wreak havoc on financial markets for a while, their existence will be a positive sign for the United States and for the world.

These different economic scenarios suggest that the U.S. dollar will be strengthening against the euro. How the Canadian dollar fares in such a situation is unclear, although the single best predictor for the Canadian dollar is still the path of world commodity prices – which is pretty much anybody’s guess.

Carl Weinberg

Chief economist, High Frequency Economics – Valhalla, N.Y.

My biggest worry for 2015 is of a default by Russia on its foreign debt. Vladimir Putin could intentionally renege on his foreign debt obligations – an Argentine approach – or Russia could just run out of liquid foreign-exchange assets. Russia owes $670-billion (U.S.) to foreigners. No one is sure who owns it all. Most of it likely is not in the hands of banks. We should remember that LTCM [Long-Term Capital Management] in the U.S. was not a bank, but its failure did a lot of damage to the financial system.

I am also waiting to see if an anti-austerity government comes to power in Greece and defaults on its debts to EFSF, the IMF and Euroland governments. EFSF has sold €180-billion ($254-billion Canadian) in bonds, backed largely by loans to Greece. In the worst case, banks and hedge funds owning these AAA bonds will find them downgraded. Some of them may fail. Euroland’s governments may have to ante up real money to recapitalize EFSF, triggering a fiscal crisis.

Finally, I worry that Britain’s current account deficit – at a record nearly 6 per cent of GDP – is wide enough to trigger a sterling crisis. The government has no strategy for external deficit reduction. A sterling crash would blow out inflation; the interest rate response would kill the economy.

#### More Related to this Story

- Canadian consumers end 2014 in dour mood

- Five ways to cut your investing costs in 2015

#### Topics:

- United Kingdom
- Japan
- Europe
- Russia
- United States of America
- China
- Energy
- Canada
- India

### In the know

- ###### Report on Business

  ##### The six biggest business stories to watch in 2015

- ###### Globe Drive

  ##### Manspreading on transit: There is an easy solution

- ###### Life

  ##### Chef Basics: Crispy and delicious – try these amazing flatbreads at home

- ###### Globe Investor

  ##### Can couple fund their kids' education and still meet retirement goals?

### Most popular videos »

- ###### News

  ##### Surveillance footage shows masked man being blown away by ATM

  ###### Life

  ##### New glasses promise a good night's sleep

  ###### Globe Drive

  ##### Surveillance footage captures bad driver struggling at gas station

  ###### Life

  ##### Need motivation to hit the gym? Try the 10-minute rule

- ###### Technology

  ##### A 'silent but powerful' wind turbine that is also disguised as a tree

  ###### Report on Business

  ##### GM issues three new recalls

  ###### News

  ##### 'They failed Tina': Thelma Favel remembers her niece

  ###### Report on Business

  ##### How a renter can build more wealth than a homeowner

- ###### News

  ##### Tour this high-security maple syrup facility that's protecting our nation's liquid gold

  ###### Report on Business

  ##### Markets could be in for a hangover in 2015

  ###### Technology

  ##### Footage shows successful launch of 3,600-kg experiment designed to reveal cosmic origins

  ###### News

  ##### Raw footage shows charred Greek ferry being towed to port in Italy

- ◀
- ●
- ●
- ●
- ▶

### Highlights

###### Report on Business

##### Bitcoin backer gets two years in prison for illicit transfers

###### Report on Business

##### Business schools nurture entrepreneurial seeds with scholarships, partnerships

### More from The Globe and Mail

###### Globe Investor

##### Five ways to invest successfully in 2015

###### Life

##### Sometimes old ugly buildings should be left well alone

### Most popular

1. ##### Sarah Palin’s Facebook photos of son stepping on dog spark outrage

2. ##### January 3: Your daily horoscope

3. ##### Edmonton murder suspect had run-ins with the law and a massive gambling debt

4. ##### Iran bashers display a dangerous lack of worldliness

5. ##### What drives anti-immigrant sentiment?

### More Top Stories

###### Leadership

##### Five essential ingredients to doing what you love for a living

###### Globe Debate

##### What drives anti-immigrant sentiment?

###### Hockey

##### Tanguay and Duchene score in shootout as Avs beat Oilers

###### Horoscopes

##### January 3: Your daily horoscope

###### Accessories

##### Stop playing parking space roulette with this app

###### Technology Video

##### Footage shows successful launch of 3,600-kg experiment designed to reveal cosmic origins

### Video

##### Fire truck overturns injuring two Missouri firefighters

##### Why 'Selma' honours the memory of Martin Luther King Jr.

##### Surveillance footage captures bad driver struggling at gas station

##### GM issues three new recalls

### Photos

##### A crane’s eye view of Toronto

##### Images from the quarter-finals at the world juniors

Add to Watchlist

##### Add to Watchlist

#####

### We've run into a glitch. Please try again later.

#####

### We've run into a glitch. Please try again later.

#####

###

x

### Customize your reading font

XS S M L XL
The quick brown fox jumps over the lazy dog The quick brown fox jumps over the lazy dog The quick brown fox jumps over the lazy dog The quick brown fox jumps over the lazy dog The quick brown fox jumps over the lazy dog